multipliers: Dynamic multipliers from an ARDL model

View source: R/dynamicStuff.R

multipliersR Documentation

Dynamic multipliers from an ARDL model

Description

This function extracts the beta (distributed lag) coefficients for a specific variable from an estimated ALM model and ARIMA(p,d,0) polynomials. It then uses them to calculate dynamic multipliers for that variable for the horizon h.

Usage

multipliers(object, parm, h = 10)

Arguments

object

An estimated ALM model object (with coefficients from coef()).

parm

Character string of the variable name.

h

Horizon for which to produce the dynamic multipliers.

Value

Numeric vector of dynamic multipliers over time

See Also

, B for creating lagged variables

Examples

## Not run: 
  # Fit a model with lagged variables
  test <- alm(drivers ~ kms + law + B(kms, 1) + B(kms, 2),
              Seatbelts, orders = c(1, 0, 0))
  multipliers(test, "kms", h=10)

## End(Not run)


greybox documentation built on Oct. 2, 2026, 5:08 p.m.