The function calls for the `xregExpander()` to create lags/leads. So, you can pass
additional parameters to it via ellipsis.
When `k > 0` (lag), the function shifts values forward in time, so `B(x, 1)`
at time `t` contains the value of `x` at time `t-1`.
When `k < 0` (lead), the function shifts values backward in time, so `B(x, -1)`
at time `t` contains the value of `x` at time `t+1`.